@@ -27,6 +27,9 @@
 #include "file-data.h"
 
 
+G_DEFINE_BOXED_TYPE(FileData, file_data, file_data_copy, file_data_free)
+
+
 FileData *
 file_data_new (void)
 {
@@ -87,18 +90,6 @@ file_data_copy (FileData *src)
 }
 
 
-GType
-file_data_get_type (void)
-{
-	static GType type = 0;
-
-	if (type == 0)
-		type = g_boxed_type_register_static ("FRFileData", (GBoxedCopyFunc) file_data_copy, (GBoxedFreeFunc) file_data_free);
-
-	return type;
-}
-
-
 void
 file_data_update_content_type (FileData *fdata)
 {
