@@ -39,6 +39,9 @@
 #include "fr-command-rar.h"
 #include "fr-command-rpm.h"
 #include "fr-command-tar.h"
+#if HAVE_JSON_GLIB
+  #include "fr-command-unarchiver.h"
+#endif
 #include "fr-command-unstuff.h"
 #include "fr-command-zip.h"
 #include "fr-command-zoo.h"
@@ -200,7 +203,7 @@ migrate_options_directory (void)
 /* -- FrRegisteredCommand -- */
 
 
-FrRegisteredCommand *
+static FrRegisteredCommand *
 fr_registered_command_new (GType command_type)
 {
 	FrRegisteredCommand  *reg_com;
@@ -241,14 +244,14 @@ fr_registered_command_new (GType command_type)
 }
 
 
-void
+G_GNUC_UNUSED static void
 fr_registered_command_ref (FrRegisteredCommand *reg_com)
 {
 	reg_com->ref++;
 }
 
 
-void
+static void
 fr_registered_command_unref (FrRegisteredCommand *reg_com)
 {
 	if (--(reg_com->ref) != 0)
@@ -260,7 +263,7 @@ fr_registered_command_unref (FrRegisteredCommand *reg_com)
 }
 
 
-FrCommandCaps
+static FrCommandCaps
 fr_registered_command_get_capabilities (FrRegisteredCommand *reg_com,
 				        const char          *mime_type)
 {
@@ -278,7 +281,7 @@ fr_registered_command_get_capabilities (FrRegisteredCommand *reg_com,
 }
 
 
-FrCommandCaps
+static FrCommandCaps
 fr_registered_command_get_potential_capabilities (FrRegisteredCommand *reg_com,
 						  const char          *mime_type)
 {
@@ -299,7 +302,7 @@ fr_registered_command_get_potential_capabilities (FrRegisteredCommand *reg_com,
 }
 
 
-void
+static void
 register_command (GType command_type)
 {
 	if (Registered_Commands == NULL)
@@ -308,7 +311,7 @@ register_command (GType command_type)
 }
 
 
-gboolean
+G_GNUC_UNUSED static gboolean
 unregister_command (GType command_type)
 {
 	int i;
@@ -355,6 +358,9 @@ register_commands (void)
 	register_command (FR_TYPE_COMMAND_ZIP);
 	register_command (FR_TYPE_COMMAND_LRZIP);
 	register_command (FR_TYPE_COMMAND_ZOO);
+#if HAVE_JSON_GLIB
+	register_command (FR_TYPE_COMMAND_UNARCHIVER);
+#endif
 }
 
 
